@@ -12,16 +12,16 @@ Import this module to get access to all known message types::
           Component.__init__(self)
           
       
-      def handle_message(self, msg, *args):
+      def handle_CORE_EV_APP_STARTED(self):
       
-          if (msg == msgs.CORE_EV_APP_STARTED):
-              self.call_service(msgs.NOTIFY_SVC_SHOW_MESSAGE,
-                                "Application started")
+          self.call_service(msgs.NOTIFY_SVC_SHOW_MESSAGE,
+                            "Application started")
 
   
 """
 
 _cnt = 0
+_names = []
 
 
 def _id_to_name(ident):
@@ -35,12 +35,18 @@ def _id_to_name(ident):
     @return: printable name of the message, e.g. "C{CORE_APPLICATION_SHUTDOWN}"
     """
 
+    try:
+        return _names[ident]
+    except:
+        return "<undefined>"
+    """    
     for k, v in globals().items():
         if (v == ident):
             return k
     #end for
     
     return "<undefined>"
+    """
 
 
 def _register(name):
@@ -53,5 +59,6 @@ def _register(name):
     global _cnt
     
     globals()[name] = _cnt
+    _names.append(name)
     _cnt += 1
 
