@@ -3,10 +3,6 @@ This package contains the media player backends.
 """
 
 from DummyBackend import DummyBackend
-from GstBackend import GstBackend
-from MPlayerBackend import MPlayerBackend
-from OSSOBackend import OSSOBackend
-from XineBackend import XineBackend
 from utils import maemo
 from mediabox import values
 from utils import mimetypes
@@ -15,21 +11,39 @@ from utils import logging
 import os
 
 
-_GST = GstBackend()
-_MPLAYER = MPlayerBackend()
-_OMS = OSSOBackend()
-_XINE = XineBackend()
 _DUMMY = DummyBackend()
 
-if (maemo.IS_MAEMO):
+if (maemo.IS_MER):
+    from XineBackend import XineBackend
+    _XINE = XineBackend()
+    _PLAYERS = {"gst": _GST,
+                "mplayer": _MPLAYER,
+                "xine": _XINE}
+    _SUFFIX = ".mer"
+    
+elif (maemo.IS_MAEMO):
+    from GstBackend import GstBackend
+    from MPlayerBackend import MPlayerBackend
+    from OSSOBackend import OSSOBackend
+    _GST = GstBackend()
+    _MPLAYER = MPlayerBackend()
+    _OMS = OSSOBackend()
     _PLAYERS = {"gst": _GST,
                 "mplayer": _MPLAYER,
                 "oms": _OMS}
+    _SUFFIX = ".maemo"
+                
 else:
+    from GstBackend import GstBackend
+    from MPlayerBackend import MPlayerBackend
+    from XineBackend import XineBackend
+    _GST = GstBackend()
+    _MPLAYER = MPlayerBackend()
+    _XINE = XineBackend()
     _PLAYERS = {"gst": _GST,
                 "mplayer": _MPLAYER,
-                "oms": _OMS,
                 "xine": _XINE}
+    _SUFFIX = ""
 
 
 _current_player = _DUMMY
@@ -37,7 +51,7 @@ _current_player = _DUMMY
 # table: mediatype -> backend name
 _MAPPING_TABLE = {}
 
-_PLAYERS_MAPPING_FILE1 = os.path.join(os.path.dirname(__file__), "players.mapping")
+_PLAYERS_MAPPING_FILE1 = os.path.join(os.path.dirname(__file__), "players.mapping" + _SUFFIX)
 _PLAYERS_MAPPING_FILE2 = os.path.join(values.USER_DIR, "players.mapping")
 
 
